@@ -370,8 +370,8 @@ class InvoicesApi(BaseApi):
 
         Cancels an invoice. The seller cannot collect payments for 
         the canceled invoice.
-        You cannot cancel an invoice in a terminal state: `PAID`, `REFUNDED`,
-        `CANCELED`, or `FAILED`.
+        You cannot cancel an invoice in the `DRAFT` state or in a terminal
+        state: `PAID`, `REFUNDED`, `CANCELED`, or `FAILED`.
 
         Args:
             invoice_id (string): The ID of the [invoice](#type-invoice) to
